@@ -4,11 +4,26 @@ from nonebot import get_driver, on_regex
 from nonebot.adapters.onebot.v11 import Bot, MessageEvent, MessageSegment
 from nonebot.log import logger
 
-from .weather_data import Weather
+from .config import Config
 from .render_pic import render
+from .weather_data import Weather
 
-api_key = get_driver().config.qweather_apikey
-api_type = get_driver().config.qweather_apitype
+plugin_config = Config.parse_obj(get_driver().config.dict())
+
+if plugin_config.qweather_apikey and plugin_config.qweather_apitype:
+    api_key = plugin_config.qweather_apikey
+    api_type = int(plugin_config.qweather_apitype)
+else:
+    from .weather_data import ConfigError
+
+    raise ConfigError("请设置 qweather_apikey 和 qweather_apitype")
+
+
+if plugin_config.debug:
+    DEBUG = True
+    logger.debug("将会保存图片到 weather.png")
+else:
+    DEBUG = False
 
 weather = on_regex(r".*?(.*)天气.*?", priority=1)
 
@@ -34,7 +49,7 @@ async def _(bot: Bot, event: MessageEvent):
 
     img = await render(w_data)
 
-    if get_driver().config.debug:
+    if DEBUG:
         debug_save_img(img)
 
     await weather.finish(MessageSegment.image(img))
@@ -42,8 +57,9 @@ async def _(bot: Bot, event: MessageEvent):
 
 def debug_save_img(img: bytes) -> None:
     from io import BytesIO
+
     from PIL import Image
 
-    logger.debug("将会保存图片到 weather.png")
+    logger.debug("保存图片到 weather.png")
     a = Image.open(BytesIO(img))
     a.save("weather.png", format="PNG")
